# skygrid

[![PyPI - Version](https://img.shields.io/pypi/v/beast-skygrid.svg)](https://pypi.org/project/beast-skygrid)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/beast-skygrid.svg)](https://pypi.org/project/beast-skygrid)

![](images/skygrid.png)

## Installation

```console
pip install beast-skygrid
```

## License

`skygrid` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
